@@ -1,6 +1,5 @@
-#[cfg(any(feature = "google-iam-v1-logging",))]
+#[cfg(any(feature = "google-iam-v1-logging"))]
 pub mod logging;
-
 /// Encapsulates settings provided to GetIamPolicy.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetPolicyOptions {
@@ -22,7 +21,7 @@ pub struct GetPolicyOptions {
     /// To learn which resources support conditions in their IAM policies, see the
     /// [IAM
     /// documentation](<https://cloud.google.com/iam/help/conditions/resource-policies>).
-    #[prost(int32, tag = "1")]
+    #[prost(int32, tag="1")]
     pub requested_policy_version: i32,
 }
 /// An Identity and Access Management (IAM) policy, which specifies access
@@ -118,7 +117,7 @@ pub struct Policy {
     ///
     /// To learn which resources support conditions in their IAM policies, see the
     /// [IAM documentation](<https://cloud.google.com/iam/help/conditions/resource-policies>).
-    #[prost(int32, tag = "1")]
+    #[prost(int32, tag="1")]
     pub version: i32,
     /// Associates a list of `members`, or principals, with a `role`. Optionally,
     /// may specify a `condition` that determines how and when the `bindings` are
@@ -130,10 +129,10 @@ pub struct Policy {
     /// different roles to `user:alice@example.com`, and not to any other
     /// principal, then you can add another 1,450 principals to the `bindings` in
     /// the `Policy`.
-    #[prost(message, repeated, tag = "4")]
+    #[prost(message, repeated, tag="4")]
     pub bindings: ::prost::alloc::vec::Vec<Binding>,
     /// Specifies cloud audit logging configuration for this policy.
-    #[prost(message, repeated, tag = "6")]
+    #[prost(message, repeated, tag="6")]
     pub audit_configs: ::prost::alloc::vec::Vec<AuditConfig>,
     /// `etag` is used for optimistic concurrency control as a way to help
     /// prevent simultaneous updates of a policy from overwriting each other.
@@ -147,7 +146,7 @@ pub struct Policy {
     /// whenever you call `setIamPolicy`. If you omit this field, then IAM allows
     /// you to overwrite a version `3` policy with a version `1` policy, and all of
     /// the conditions in the version `3` policy are lost.
-    #[prost(bytes = "bytes", tag = "3")]
+    #[prost(bytes="bytes", tag="3")]
     pub etag: ::prost::bytes::Bytes,
 }
 /// Associates `members`, or principals, with a `role`.
@@ -155,7 +154,7 @@ pub struct Policy {
 pub struct Binding {
     /// Role that is assigned to the list of `members`, or principals.
     /// For example, `roles/viewer`, `roles/editor`, or `roles/owner`.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub role: ::prost::alloc::string::String,
     /// Specifies the principals requesting access for a Cloud Platform resource.
     /// `members` can have the following values:
@@ -201,7 +200,7 @@ pub struct Binding {
     ///    users of that domain. For example, `google.com` or `example.com`.
     ///
     ///
-    #[prost(string, repeated, tag = "2")]
+    #[prost(string, repeated, tag="2")]
     pub members: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
     /// The condition that is associated with this binding.
     ///
@@ -215,7 +214,7 @@ pub struct Binding {
     /// To learn which resources support conditions in their IAM policies, see the
     /// [IAM
     /// documentation](<https://cloud.google.com/iam/help/conditions/resource-policies>).
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub condition: ::core::option::Option<super::super::r#type::Expr>,
 }
 /// Specifies the audit configuration for a service.
@@ -274,10 +273,10 @@ pub struct AuditConfig {
     /// Specifies a service that will be enabled for audit logging.
     /// For example, `storage.googleapis.com`, `cloudsql.googleapis.com`.
     /// `allServices` is a special value that covers all services.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub service: ::prost::alloc::string::String,
     /// The configuration for logging of each type of permission.
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub audit_log_configs: ::prost::alloc::vec::Vec<AuditLogConfig>,
 }
 /// Provides the configuration for logging a type of permissions.
@@ -302,12 +301,12 @@ pub struct AuditConfig {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct AuditLogConfig {
     /// The log type that this config enables.
-    #[prost(enumeration = "audit_log_config::LogType", tag = "1")]
+    #[prost(enumeration="audit_log_config::LogType", tag="1")]
     pub log_type: i32,
     /// Specifies the identities that do not cause logging for this type of
     /// permission.
     /// Follows the same format of \[Binding.members][google.iam.v1.Binding.members\].
-    #[prost(string, repeated, tag = "2")]
+    #[prost(string, repeated, tag="2")]
     pub exempted_members: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Nested message and enum types in `AuditLogConfig`.
@@ -331,10 +330,10 @@ pub mod audit_log_config {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct PolicyDelta {
     /// The delta for Bindings between two policies.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub binding_deltas: ::prost::alloc::vec::Vec<BindingDelta>,
     /// The delta for AuditConfigs between two policies.
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub audit_config_deltas: ::prost::alloc::vec::Vec<AuditConfigDelta>,
 }
 /// One delta entry for Binding. Each individual change (only one member in each
@@ -343,20 +342,20 @@ pub struct PolicyDelta {
 pub struct BindingDelta {
     /// The action that was performed on a Binding.
     /// Required
-    #[prost(enumeration = "binding_delta::Action", tag = "1")]
+    #[prost(enumeration="binding_delta::Action", tag="1")]
     pub action: i32,
     /// Role that is assigned to `members`.
     /// For example, `roles/viewer`, `roles/editor`, or `roles/owner`.
     /// Required
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub role: ::prost::alloc::string::String,
     /// A single identity requesting access for a Cloud Platform resource.
     /// Follows the same format of Binding.members.
     /// Required
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub member: ::prost::alloc::string::String,
     /// The condition that is associated with this binding.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub condition: ::core::option::Option<super::super::r#type::Expr>,
 }
 /// Nested message and enum types in `BindingDelta`.
@@ -379,23 +378,23 @@ pub mod binding_delta {
 pub struct AuditConfigDelta {
     /// The action that was performed on an audit configuration in a policy.
     /// Required
-    #[prost(enumeration = "audit_config_delta::Action", tag = "1")]
+    #[prost(enumeration="audit_config_delta::Action", tag="1")]
     pub action: i32,
     /// Specifies a service that was configured for Cloud Audit Logging.
     /// For example, `storage.googleapis.com`, `cloudsql.googleapis.com`.
     /// `allServices` is a special value that covers all services.
     /// Required
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub service: ::prost::alloc::string::String,
     /// A single identity that is exempted from "data access" audit
     /// logging for the `service` specified above.
     /// Follows the same format of Binding.members.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub exempted_member: ::prost::alloc::string::String,
     /// Specifies the log_type that was be enabled. ADMIN_ACTIVITY is always
     /// enabled, and cannot be configured.
     /// Required
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub log_type: ::prost::alloc::string::String,
 }
 /// Nested message and enum types in `AuditConfigDelta`.
@@ -417,20 +416,20 @@ pub mod audit_config_delta {
 pub struct SetIamPolicyRequest {
     /// REQUIRED: The resource for which the policy is being specified.
     /// See the operation documentation for the appropriate value for this field.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub resource: ::prost::alloc::string::String,
     /// REQUIRED: The complete policy to be applied to the `resource`. The size of
     /// the policy is limited to a few 10s of KB. An empty policy is a
     /// valid policy but certain Cloud Platform services (such as Projects)
     /// might reject them.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub policy: ::core::option::Option<Policy>,
     /// OPTIONAL: A FieldMask specifying which fields of the policy to modify. Only
     /// the fields in the mask will be modified. If no mask is provided, the
     /// following default mask is used:
     ///
     /// `paths: "bindings, etag"`
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub update_mask: ::core::option::Option<::prost_types::FieldMask>,
 }
 /// Request message for `GetIamPolicy` method.
@@ -438,11 +437,11 @@ pub struct SetIamPolicyRequest {
 pub struct GetIamPolicyRequest {
     /// REQUIRED: The resource for which the policy is being requested.
     /// See the operation documentation for the appropriate value for this field.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub resource: ::prost::alloc::string::String,
     /// OPTIONAL: A `GetPolicyOptions` object for specifying options to
     /// `GetIamPolicy`.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub options: ::core::option::Option<GetPolicyOptions>,
 }
 /// Request message for `TestIamPermissions` method.
@@ -450,13 +449,13 @@ pub struct GetIamPolicyRequest {
 pub struct TestIamPermissionsRequest {
     /// REQUIRED: The resource for which the policy detail is being requested.
     /// See the operation documentation for the appropriate value for this field.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub resource: ::prost::alloc::string::String,
     /// The set of permissions to check for the `resource`. Permissions with
     /// wildcards (such as '*' or 'storage.*') are not allowed. For more
     /// information see
     /// [IAM Overview](<https://cloud.google.com/iam/docs/overview#permissions>).
-    #[prost(string, repeated, tag = "2")]
+    #[prost(string, repeated, tag="2")]
     pub permissions: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// Response message for `TestIamPermissions` method.
@@ -464,39 +463,39 @@ pub struct TestIamPermissionsRequest {
 pub struct TestIamPermissionsResponse {
     /// A subset of `TestPermissionsRequest.permissions` that the caller is
     /// allowed.
-    #[prost(string, repeated, tag = "1")]
+    #[prost(string, repeated, tag="1")]
     pub permissions: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod iam_policy_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " API Overview"]
-    #[doc = ""]
-    #[doc = ""]
-    #[doc = " Manages Identity and Access Management (IAM) policies."]
-    #[doc = ""]
-    #[doc = " Any implementation of an API that offers access control features"]
-    #[doc = " implements the google.iam.v1.IAMPolicy interface."]
-    #[doc = ""]
-    #[doc = " ## Data model"]
-    #[doc = ""]
-    #[doc = " Access control is applied when a principal (user or service account), takes"]
-    #[doc = " some action on a resource exposed by a service. Resources, identified by"]
-    #[doc = " URI-like names, are the unit of access control specification. Service"]
-    #[doc = " implementations can choose the granularity of access control and the"]
-    #[doc = " supported permissions for their resources."]
-    #[doc = " For example one database service may allow access control to be"]
-    #[doc = " specified only at the Table level, whereas another might allow access control"]
-    #[doc = " to also be specified at the Column level."]
-    #[doc = ""]
-    #[doc = " ## Policy Structure"]
-    #[doc = ""]
-    #[doc = " See google.iam.v1.Policy"]
-    #[doc = ""]
-    #[doc = " This is intentionally not a CRUD style API because access control policies"]
-    #[doc = " are created and deleted implicitly with the resources to which they are"]
-    #[doc = " attached."]
+    /// API Overview
+    ///
+    ///
+    /// Manages Identity and Access Management (IAM) policies.
+    ///
+    /// Any implementation of an API that offers access control features
+    /// implements the google.iam.v1.IAMPolicy interface.
+    ///
+    /// ## Data model
+    ///
+    /// Access control is applied when a principal (user or service account), takes
+    /// some action on a resource exposed by a service. Resources, identified by
+    /// URI-like names, are the unit of access control specification. Service
+    /// implementations can choose the granularity of access control and the
+    /// supported permissions for their resources.
+    /// For example one database service may allow access control to be
+    /// specified only at the Table level, whereas another might allow access control
+    /// to also be specified at the Column level.
+    ///
+    /// ## Policy Structure
+    ///
+    /// See google.iam.v1.Policy
+    ///
+    /// This is intentionally not a CRUD style API because access control policies
+    /// are created and deleted implicitly with the resources to which they are
+    /// attached.
     #[derive(Debug, Clone)]
     pub struct IamPolicyClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -504,8 +503,8 @@ pub mod iam_policy_client {
     impl<T> IamPolicyClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -524,81 +523,96 @@ pub mod iam_policy_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             IamPolicyClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Sets the access control policy on the specified resource. Replaces any"]
-        #[doc = " existing policy."]
-        #[doc = ""]
-        #[doc = " Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors."]
+        /// Sets the access control policy on the specified resource. Replaces any
+        /// existing policy.
+        ///
+        /// Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors.
         pub async fn set_iam_policy(
             &mut self,
             request: impl tonic::IntoRequest<super::SetIamPolicyRequest>,
         ) -> Result<tonic::Response<super::Policy>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/google.iam.v1.IAMPolicy/SetIamPolicy");
+            let path = http::uri::PathAndQuery::from_static(
+                "/google.iam.v1.IAMPolicy/SetIamPolicy",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Gets the access control policy for a resource."]
-        #[doc = " Returns an empty policy if the resource exists and does not have a policy"]
-        #[doc = " set."]
+        /// Gets the access control policy for a resource.
+        /// Returns an empty policy if the resource exists and does not have a policy
+        /// set.
         pub async fn get_iam_policy(
             &mut self,
             request: impl tonic::IntoRequest<super::GetIamPolicyRequest>,
         ) -> Result<tonic::Response<super::Policy>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/google.iam.v1.IAMPolicy/GetIamPolicy");
+            let path = http::uri::PathAndQuery::from_static(
+                "/google.iam.v1.IAMPolicy/GetIamPolicy",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Returns permissions that a caller has on the specified resource."]
-        #[doc = " If the resource does not exist, this will return an empty set of"]
-        #[doc = " permissions, not a `NOT_FOUND` error."]
-        #[doc = ""]
-        #[doc = " Note: This operation is designed to be used for building permission-aware"]
-        #[doc = " UIs and command-line tools, not for authorization checking. This operation"]
-        #[doc = " may \"fail open\" without warning."]
+        /// Returns permissions that a caller has on the specified resource.
+        /// If the resource does not exist, this will return an empty set of
+        /// permissions, not a `NOT_FOUND` error.
+        ///
+        /// Note: This operation is designed to be used for building permission-aware
+        /// UIs and command-line tools, not for authorization checking. This operation
+        /// may "fail open" without warning.
         pub async fn test_iam_permissions(
             &mut self,
             request: impl tonic::IntoRequest<super::TestIamPermissionsRequest>,
         ) -> Result<tonic::Response<super::TestIamPermissionsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/google.iam.v1.IAMPolicy/TestIamPermissions");
+            let path = http::uri::PathAndQuery::from_static(
+                "/google.iam.v1.IAMPolicy/TestIamPermissions",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
     }
